Requirements and Installation
=============================

Requirements
------------

Runtime
^^^^^^^

* Django 1.7+
* django-templatetag-handlebars 1.3.2+

Development
^^^^^^^^^^^

In addition to Runtime requirements above:

* sqlite3 (default) or any other RDBMS supported by Django
* Sphinx (only to generate docs)

Installation
------------

You can pip install from PyPI::

    pip install django-iprestrict

Alternately, you can select a release from Github and install that
with pip::

    pip install https://github.com/muccg/django-iprestrict/archive/0.4.0.zip
